@@ -15,11 +15,16 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.airbyte.hooks.airbyte import AirbyteHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class AirbyteTriggerSyncOperator(BaseOperator):
     """
@@ -30,34 +35,29 @@ class AirbyteTriggerSyncOperator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:AirbyteTriggerSyncOperator`
 
-    :param airbyte_conn_id: Required. The name of the Airflow connection to get connection
-        information for Airbyte.
-    :type airbyte_conn_id: str
+    :param airbyte_conn_id: Optional. The name of the Airflow connection to get connection
+        information for Airbyte. Defaults to "airbyte_default".
     :param connection_id: Required. The Airbyte ConnectionId UUID between a source and destination.
-    :type connection_id: str
     :param asynchronous: Optional. Flag to get job_id after submitting the job to the Airbyte API.
         This is useful for submitting long running jobs and
-        waiting on them asynchronously using the AirbyteJobSensor.
-    :type asynchronous: bool
-    :param api_version: Optional. Airbyte API version.
-    :type api_version: str
+        waiting on them asynchronously using the AirbyteJobSensor. Defaults to False.
+    :param api_version: Optional. Airbyte API version. Defaults to "v1".
     :param wait_seconds: Optional. Number of seconds between checks. Only used when ``asynchronous`` is False.
-    :type wait_seconds: float
+        Defaults to 3 seconds.
     :param timeout: Optional. The amount of time, in seconds, to wait for the request to complete.
-        Only used when ``asynchronous`` is False.
-    :type timeout: float
+        Only used when ``asynchronous`` is False. Defaults to 3600 seconds (or 1 hour).
     """
 
-    template_fields = ('connection_id',)
+    template_fields: Sequence[str] = ("connection_id",)
 
     def __init__(
         self,
         connection_id: str,
         airbyte_conn_id: str = "airbyte_default",
-        asynchronous: Optional[bool] = False,
-        api_version: Optional[str] = "v1",
-        wait_seconds: Optional[float] = 3,
-        timeout: Optional[float] = 3600,
+        asynchronous: bool = False,
+        api_version: str = "v1",
+        wait_seconds: float = 3,
+        timeout: float = 3600,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -68,16 +68,22 @@ class AirbyteTriggerSyncOperator(BaseOperator):
         self.wait_seconds = wait_seconds
         self.asynchronous = asynchronous
 
-    def execute(self, context) -> None:
-        """Create Airbyte Job and wait to finish"""
-        hook = AirbyteHook(airbyte_conn_id=self.airbyte_conn_id, api_version=self.api_version)
-        job_object = hook.submit_sync_connection(connection_id=self.connection_id)
-        job_id = job_object.json()['job']['id']
+    def execute(self, context: Context) -> None:
+        """Create Airbyte Job and wait to finish."""
+        self.hook = AirbyteHook(airbyte_conn_id=self.airbyte_conn_id, api_version=self.api_version)
+        job_object = self.hook.submit_sync_connection(connection_id=self.connection_id)
+        self.job_id = job_object.json()["job"]["id"]
 
-        self.log.info("Job %s was submitted to Airbyte Server", job_id)
+        self.log.info("Job %s was submitted to Airbyte Server", self.job_id)
         if not self.asynchronous:
-            self.log.info('Waiting for job %s to complete', job_id)
-            hook.wait_for_job(job_id=job_id, wait_seconds=self.wait_seconds, timeout=self.timeout)
-            self.log.info('Job %s completed successfully', job_id)
+            self.log.info("Waiting for job %s to complete", self.job_id)
+            self.hook.wait_for_job(job_id=self.job_id, wait_seconds=self.wait_seconds, timeout=self.timeout)
+            self.log.info("Job %s completed successfully", self.job_id)
 
-        return job_id
+        return self.job_id
+
+    def on_kill(self):
+        """Cancel the job if task is cancelled."""
+        if self.job_id:
+            self.log.info("on_kill: cancel the airbyte Job %s", self.job_id)
+            self.hook.cancel_job(self.job_id)
